#' Generate HTML file(s) containing code used to run differential expression analysis.
#' 
#' A function to extract the code used to generate differential expression results from saved result objects (typically obtained by \code{\link{runDiffExp}}), and to write the code to HTML files. This requires that the code was saved as a string in the \code{code} slot of the result object, which is done automatically by \code{\link{runDiffExp}}. If the differential expression analysis was performed with functions outside \code{compcodeR}, the code has to be added manually to the result object. 
#' 
#' @param input.files A vector with paths to one or several .rds objects containing the results from differential expression analysis. One code HTML file is generated for each element in the vector. 
#' @param output.directory The path to the directory where the code HTML files will be saved.
#' @export
#' @author Charlotte Soneson
#' @examples
#' mydata.obj <- generateSyntheticData(dataset = "mydata", n.vars = 12500, 
#'                                     samples.per.cond = 5, n.diffexp = 1250, 
#'                                     output.file = "mydata.rds")
#' runDiffExp(data.file = "mydata.rds", result.extent = "voom.limma", 
#'            Rmdfunction = "voom.limma.createRmd", output.directory = ".", 
#'            norm.method = "TMM")
#' generateCodeHTMLs("mydata_voom.limma.rds", ".")
generateCodeHTMLs = function(input.files, output.directory) {
  for (i in 1:length(input.files)) {
    temp <- as.character(input.files[i])
    ## Extract only the filename (that will be used to name the code file)
    filename <- strsplit(strsplit(temp,"/")[[1]][length(strsplit(temp,"/")[[1]])], 
                         ".rds")[[1]][1]
    ## Check that the code is available
    rdsobj <- readRDS(temp)
    if (is.null(rdsobj$code)) {
      message(paste("Code not available in", input.files[i]))
    } else {
      ## Create the code file
      codefile <- file.path(output.directory, paste(filename,  "_code.md", sep = ""))
      fileConn <- file(codefile)
      
      ## Write the code to the file
      writeLines(text = rdsobj$code, con = fileConn)
      close(fileConn)
      
      ## Generate HTML file
      markdownToHTML(file = codefile,
                     output = str_replace(codefile, pattern = ".md", replacement = ".html"),
                     title = 'Code')
      
      ## Remove the temporary markdown file
      file.remove(codefile)
    }
  }
}