#' Generate synthetic data sets
#' 
#' Generate synthetic count data sets, following the simulation strategy detailed in Soneson and Delorenzi (2013). 
#' 
#' @param dataset A name or identifier for the data set/simulation settings.
#' @param n.vars The number of simulated genes. Based on the filtering conditions (\code{filter.threshold.total} and \code{filter.threshold.mediancpm}), the number of genes in the final data set may be lower than this number. 
#' @param samples.per.cond The number of samples per condition.
#' @param n.diffexp The number of differentially expressed genes.
#' @param repl.id A replicate ID for the specific simulation instance. Useful for example when generating multiple count matrices with the same simulation settings. 
#' @param seqdepth The base sequencing depth (total number of mapped reads). This number is multiplied by a value drawn uniformly between \code{minfact} and \code{maxfact} for the individual samples to generate data with different actual sequencing depths. 
#' @param minfact,maxfact The minimum and maximum for the uniform distribution used to generate factors that are multiplied with \code{seqdepth} to generate individual sequencing depths for the simulated samples. 
#' @param fraction.upregulated The fraction of the differentially expressed genes that is upregulated in condition 2 compared to condition 1. 
#' @param between.group.diffdisp Whether or not the dispersion should be allowed to be different between the conditions.
#' @param filter.threshold.total The filter threshold on the total count for a gene across all samples. All genes for which the total count across all samples is less than the threshold will be filtered out.
#' @param filter.threshold.mediancpm The filter threshold on the median count per million (cpm) for a gene across all samples. All genes for which the median cpm across all samples is less than the threshold will be filtered out.
#' @param fraction.non.overdispersed The fraction of the genes that should be simulated according to a Poisson distribution, without overdispersion. The non-overdispersed genes will be divided proportionally between the upregulated, downregulated and non-differentially expressed genes.
#' @param random.outlier.high.prob The fraction of 'random' outliers with unusually high counts.
#' @param random.outlier.low.prob The fraction of 'random' outliers with unusually low counts.
#' @param single.outlier.high.prob The fraction of 'single' outliers with unusually high counts.
#' @param single.outlier.low.prob The fraction of 'single' outliers with unusually low counts.
#' @param effect.size The strength of the differential expression, i.e., the effect size, between the two conditions.
#' @param output.file If not \code{NULL}, the path to the file where the data should be saved. The extension should be \code{.rds}, if not it will be changed.
#' @return The function returns a data object, in the form of a list with the following named elements:
#' \itemize{
#' \item \code{count.matrix}: The simulated count matrix, with each row representing a gene and each column representing a sample.
#' \item \code{variable.annotations}: a data frame (with number of rows equal to the number of variables in the data set) with the following named columns:
#' \itemize{
#' \item \code{truedispersions.S1}: the true dispersion for each gene in condition S1.
#' \item \code{truedispersions.S2}: the true dispersion for each gene in condition S2.
#' \item \code{truemeans.S1}: the true mean value for each gene in condition S1.
#' \item \code{truemeans.S2}: the true mean value for each gene in condition S2.
#' \item \code{n.random.outliers.up.S1}: the number of 'random' outliers with extremely high counts for each gene in condition S1.
#' \item \code{n.random.outliers.up.S2}: the number of 'random' outliers with extremely high counts for each gene in condition S2.
#' \item \code{n.random.outliers.down.S1}: the number of 'random' outliers with extremely low counts for each gene in condition S1.
#' \item \code{n.random.outliers.down.S2}: the number of 'random' outliers with extremely low counts for each gene in condition S2.
#' \item \code{n.single.outliers.up.S1}: the number of 'single' outliers with extremely high counts for each gene in condition S1.
#' \item \code{n.single.outliers.up.S2}: the number of 'single' outliers with extremely high counts for each gene in condition S2.
#' \item \code{n.single.outliers.down.S1}: the number of 'single' outliers with extremely low counts for each gene in condition S1.
#' \item \code{n.single.outliers.down.S2}: the number of 'single' outliers with extremely low counts for each gene in condition S2.
#' \item \code{M.value}: the M-value (observed log2 fold change between condition S1 and condition S2) for each gene.
#' \item \code{A.value}: the A-value (observed average expression level across condition S1 and condition S2) for each gene.
#' \item \code{truelog2foldchanges}: the true (simulated) log2 fold changes between condition S1 and condition S2.
#' \item \code{upregulation}: a binary vector indicating which genes are simulated to be upregulated in condition S2 compared to condition S1.
#' \item \code{downregulation}: a binary vector indicating which genes are simulated to be downregulated in condition S2 compared to condition S1.
#' \item \code{differential.expression}: a binary vector indicating which genes are simulated to be differentially expressed in condition S2 compared to condition S1.
#' }
#' \item \code{sample.annotations}: a data frame (with the number of rows equal to the number of samples) with the following named columns:
#' \itemize{
#' \item \code{condition}: the class of each sample.
#' \item \code{depth.factor}: the depth factor for each sample. This factor, multiplied by \code{seqdepth}, is used as the simulated library size for the sample.
#' }
#' \item \code{filtering}: information about the filtering that has been applied (total count and median cpm).
#' \item \code{info.parameters}: a list summarizing the parameters that have been used for the simulation (see the description above of the arguments to the function for more information):
#' \itemize{
#' \item \code{dataset}
#' \item \code{samples.per.cond}
#' \item \code{n.diffexp}
#' \item \code{repl.id}
#' \item \code{seqdepth}
#' \item \code{minfact}
#' \item \code{maxfact}
#' \item \code{fraction.upregulated}
#' \item \code{between.group.diffdisp}
#' \item \code{filter.threshold.total}
#' \item \code{filter.threshold.mediancpm}
#' \item \code{fraction.non.overdispersed}
#' \item \code{random.outlier.high.prob}
#' \item \code{random.outlier.low.prob}
#' \item \code{single.outlier.high.prob}
#' \item \code{single.outlier.low.prob}
#' \item \code{effect.size}
#' \item \code{uID}: a unique ID that is given to each simulated data set.
#' }
#' }
#' If \code{output.file} is not \code{NULL}, the object is saved with the given \code{output.file} (which should have an \code{.rds} extension).
#' @export
#' @author Charlotte Soneson
#' @examples
#' mydata.obj <- generateSyntheticData(dataset = "mydata", n.vars = 12500, 
#'                                     samples.per.cond = 5, n.diffexp = 1250, 
#'                                     output.file = "mydata.rds")
#' @references
#' Soneson C and Delorenzi M (2013): A comparison of methods for differential expression analysis of RNA-seq data. BMC Bioinformatics 14:91
#' 
#' Cheung VG, Nayak RR, Wang IX, Elwyn S, Cousins SM, Morley M and Spielman RS (2010): Polymorphic cis- and trans-regulation of human gene expression. PLoS Biology 8(9):e1000480
#' 
#' Frazee AC, Langmead B and Leek JT (2011): ReCount: a multi-experiment resource of analysis-ready RNA-seq gene count datasets. BMC Bioinformatics 12:449
#' 
#' Pickrell JK, Marioni JC, Pai AA, Degner JF, Engelhardt BE, Nkadori E, Veyrieras JB, Stephens M, Gilad Y and Pritchard JK (2010): Understanding mechanisms underlying human gene expression variation with RNA sequencing. Nature 464, 768-772
#' 
#' Robles JA, Qureshi SE, Stephen SJ, Wilson SR, Burden CJ and Taylor JM (2012): Efficient experimental design and analysis strategies for the detection of differential expression using RNA-sequencing. BMC Genomics 13:484
generateSyntheticData = function(dataset, n.vars, samples.per.cond, n.diffexp, repl.id = 1, 
                                 seqdepth = 1e7, minfact = 0.7, maxfact = 1.4, 
                                 fraction.upregulated = 1, between.group.diffdisp = FALSE, 
                                 filter.threshold.total = 1, filter.threshold.mediancpm = 0, 
                                 fraction.non.overdispersed = 0, random.outlier.high.prob = 0, 
                                 random.outlier.low.prob = 0, single.outlier.high.prob = 0, 
                                 single.outlier.low.prob = 0, effect.size = 1.5, 
                                 output.file = NULL) {
  
  ## Generate a unique ID for the data set
  uID <- paste(sample(c(0:9, letters, LETTERS), 10, replace = TRUE), collapse = "")

	## Define conditions
  condition <- rep(c(1, 2), each = samples.per.cond)
  S1 <- which(condition == 1)
  S2 <- which(condition == 2)

	## Define sets of upregulated, downregulated and non-differentially regulated genes
	n.upregulated <- floor(fraction.upregulated * n.diffexp)
	if (fraction.upregulated != 0 & n.diffexp != 0) {
		genes.upreg <- 1:n.upregulated
	} else {
		genes.upreg <- NULL
	}
	if (fraction.upregulated != 1 & n.diffexp != 0) {
		genes.downreg <- (n.upregulated + 1):n.diffexp
	} else {
		genes.downreg <- NULL
	}
	genes.nonreg <- setdiff(1:n.vars, union(genes.upreg, genes.downreg))

	### Differentially expressed genes
	differential.expression <- rep(0, n.vars)
	differential.expression[genes.upreg] <- 1
	differential.expression[genes.downreg] <- 1
	upregulation <- rep(0, n.vars)
	upregulation[genes.upreg] <- 1
	downregulation <- rep(0, n.vars)
	downregulation[genes.downreg] <- 1
	
	### Load mu and phi estimates from real data (Pickrell data set and Cheung data set)
	mu.phi.estimates <- system.file("extdata", "Pickrell.Cheung.Mu.Phi.Estimates.rds",
                                  package = "compcodeR")
	mu.phi.estimates <- readRDS(mu.phi.estimates)
	mu.estimates <- mu.phi.estimates$pickrell.cheung.mu
	phi.estimates <- mu.phi.estimates$pickrell.cheung.phi
	
	### Sample a mu and a phi for each gene in condition S1
	to.include <- sample(1:length(mu.estimates), n.vars)
	truedispersions.S1 <- phi.estimates[to.include]
	truemeans.S1 <- mu.estimates[to.include]
	
	### Generate sequencing depths (nfacts * Nk)
	nfacts <- runif(2 * samples.per.cond, min = minfact, max = maxfact)
	seq.depths <- nfacts * seqdepth

	### If not all genes are overdispersed, let some of them be Poisson distributed (dispersion = 0)
	overdispersed <- rep(1, n.vars)
	if (fraction.non.overdispersed > 0) {
		overdispersed[genes.upreg[1:round(fraction.non.overdispersed * length(genes.upreg))]] <- 0
		overdispersed[genes.downreg[1:round(fraction.non.overdispersed * length(genes.downreg))]] <- 0
		overdispersed[genes.nonreg[1:round(fraction.non.overdispersed * length(genes.nonreg))]] <- 0
	}

	### Find rates of mapping to each gene in each condition
	prob.S1 <- truemeans.S1
	prob.S2 <- rep(0, length(prob.S1))
	
	for (i in 1:n.vars) {
		if (i %in% genes.upreg) {
			prob.S2[i] <- (effect.size + rexp(1, rate = 1)) * prob.S1[i]
		} else {
			if (i %in% genes.downreg) {
				prob.S2[i] <- 1/(effect.size + rexp(1, rate = 1)) * prob.S1[i]
			} else {
				prob.S2[i] <- prob.S1[i]
			}
		}
	}
	true.log2foldchange <- log2(prob.S2/prob.S1)
	sum.S1 <- sum(prob.S1)
	sum.S2 <- sum(prob.S2)
	
	### Find new dispersions for condition S2, depending on what prob.S2 is. 
  ### From the mu/phi estimates, sample a phi value from 
	### the pairs where mu is similar to prob.S2.
	truedispersions.S2 <- truedispersions.S1
	if (between.group.diffdisp == TRUE) {
		for (i in 1:length(truedispersions.S2)) {
			sample.base <- phi.estimates[abs(log10(mu.estimates) - log10(prob.S2[i])) < 0.05]
			if (length(sample.base) < 50) {
				sample.base <- phi.estimates[order(abs(log10(mu.estimates) - log10(prob.S2[i])))][1:500]
			}
			truedispersions.S2[i] <- sample(sample.base, 1)
		}
	}
	
	truedispersions.S1 <- truedispersions.S1 * overdispersed
	truedispersions.S2 <- truedispersions.S2 * overdispersed
	
	### Initialize data matrix
	Z <- matrix(0, n.vars, length(S1) + length(S2))
	
	### Generate data
	for (i in 1:n.vars) {
		for (j in 1:ncol(Z)) {
			if (j %in% S1) {
				if (overdispersed[i] == 1) {
					Z[i, j] <- rnbinom(n = 1, mu = prob.S1[i]/sum.S1 * seq.depths[j], 
                             size = 1/truedispersions.S1[i])
				} else {
					Z[i, j] <- rpois(n = 1, lambda = prob.S1[i]/sum.S1 * seq.depths[j])
				}
			} else {
				if (overdispersed[i] == 1) {
					Z[i, j] <- rnbinom(n = 1, mu = prob.S2[i]/sum.S2 * seq.depths[j], 
                             size = 1/truedispersions.S2[i])
				} else {
					Z[i, j] <- rpois(n = 1, lambda = prob.S2[i]/sum.S2 * seq.depths[j])
				}
			}
		}
	}

	### Add 'random' outliers
	random.outliers <- matrix(0, nrow(Z), ncol(Z))
	random.outliers.factor <- matrix(1, nrow(Z), ncol(Z))
	if (random.outlier.high.prob != 0 | random.outlier.low.prob != 0) {
		for (i in 1:nrow(Z)) {
			for (j in 1:ncol(Z)) {
        tmp <- runif(1)
				if (tmp < random.outlier.high.prob) {
          random.outliers[i, j] <- 1
          random.outliers.factor[i, j] <- runif(1, min = 5, max = 10)
				} else if (tmp < random.outlier.low.prob + random.outlier.high.prob) {
          random.outliers[i, j] <- (-1)
          random.outliers.factor[i, j] <- 1/runif(1, min = 5, max = 10)
				}
			}
		}
    Z <- round(random.outliers.factor * Z)
	}

	### Add 'single' outliers
	has.single.outlier <- rep(0, n.vars)
	single.outliers <- matrix(0, nrow(Z), ncol(Z))
  single.outliers.factor <- matrix(1, nrow(Z), ncol(Z))
	if (single.outlier.high.prob != 0 | single.outlier.low.prob != 0) {
		has.single.outlier[genes.upreg[1:floor((single.outlier.high.prob + 
                                              single.outlier.low.prob) * length(genes.upreg))]] <- 1
		has.single.outlier[genes.downreg[1:floor((single.outlier.high.prob + 
                                                single.outlier.low.prob) * length(genes.downreg))]] <- 1
		has.single.outlier[genes.nonreg[1:floor((single.outlier.high.prob + 
                                               single.outlier.low.prob) * length(genes.nonreg))]] <- 1
			
		for (i in 1:nrow(Z)) {
			if (has.single.outlier[i] == 1) {
				the.sample <- sample(1:(ncol(Z)), 1)
        if (runif(1) < (single.outlier.high.prob/(single.outlier.high.prob + 
                                                    single.outlier.low.prob))) {
					single.outliers[i, the.sample] <- 1
          single.outliers.factor[i, the.sample] <- runif(1, min = 5, max = 10)
				} else {
					single.outliers[i, the.sample] <- (-1)
          single.outliers.factor[i, the.sample] <- 1/runif(1, min = 5, max = 10)
				}
			}
		}
    Z <- round(single.outliers.factor * Z)
	}
	
	### Assign variable names to rows
	rownames(Z) <- 1:n.vars
	
	### Find number of outliers (random, single, up, down) in each group
	n.random.outliers.up.S1 = apply(random.outliers[, S1] > 0, 1, sum)
	n.random.outliers.up.S2 = apply(random.outliers[, S2] > 0, 1, sum)
	n.random.outliers.down.S1 = apply(random.outliers[, S1] < 0, 1, sum)
	n.random.outliers.down.S2 = apply(random.outliers[, S2] < 0, 1, sum)
	n.single.outliers.up.S1 = apply(single.outliers[, S1] > 0, 1, sum)
	n.single.outliers.up.S2 = apply(single.outliers[, S2] > 0, 1, sum)
	n.single.outliers.down.S1 = apply(single.outliers[, S1] < 0, 1, sum)
	n.single.outliers.down.S2 = apply(single.outliers[, S2] < 0, 1, sum)
	
	### Normalize (TMM) and compute A and M values from the pseudocounts
	nf = calcNormFactors(Z)
	norm.factors = nf * colSums(Z)
	common.libsize = exp(mean(log(colSums(Z))))
	pseudocounts = sweep(Z + 0.5, 2, norm.factors, '/') * common.libsize
	log2.pseudocounts = log2(pseudocounts)
	M.value = apply(log2.pseudocounts[, S2], 1, mean) - apply(log2.pseudocounts[, S1], 1, mean)
	A.value = 0.5*(apply(log2.pseudocounts[, S2], 1, mean) + apply(log2.pseudocounts[, S1], 1, mean))
	
	### Create an annotation data frame
	variable.annotations = data.frame(truedispersions.S1 = truedispersions.S1, 
                                    truedispersions.S2 = truedispersions.S2, 
                                    truemeans.S1 = prob.S1, 
                                    truemeans.S2 = prob.S2, 
                                    n.random.outliers.up.S1 = n.random.outliers.up.S1, 
                                    n.random.outliers.up.S2 = n.random.outliers.up.S2, 
                                    n.random.outliers.down.S1 = n.random.outliers.down.S1, 
                                    n.random.outliers.down.S2 = n.random.outliers.down.S2, 
                                    n.single.outliers.up.S1 = n.single.outliers.up.S1, 
                                    n.single.outliers.up.S2 = n.single.outliers.up.S2, 
                                    n.single.outliers.down.S1 = n.single.outliers.down.S1, 
                                    n.single.outliers.down.S2 = n.single.outliers.down.S2, 
                                    M.value = M.value, 
                                    A.value = A.value, 
                                    truelog2foldchanges = true.log2foldchange, 
                                    upregulation = upregulation, 
                                    downregulation = downregulation, 
                                    differential.expression = differential.expression)
	rownames(variable.annotations) = rownames(Z)
	
	### Create a sample annotation data frame
	sample.annotations = data.frame(condition = condition, 
                                  depth.factor = nfacts)
	  
	### Include information about the parameters
	info.parameters = list('n.diffexp' = n.diffexp, 'fraction.upregulated' = fraction.upregulated, 
                         'between.group.diffdisp' = between.group.diffdisp, 
                         'filter.threshold.total' = filter.threshold.total, 
                         'filter.threshold.mediancpm' = filter.threshold.mediancpm, 
                         'fraction.non.overdispersed' = fraction.non.overdispersed, 
                         'random.outlier.high.prob' = random.outlier.high.prob,
                         'random.outlier.low.prob' = random.outlier.low.prob,
                         'single.outlier.high.prob' = single.outlier.high.prob, 
                         'single.outlier.low.prob' = single.outlier.low.prob,
                         'effect.size' = effect.size, 'samples.per.cond' = samples.per.cond, 
                         'repl.id' = repl.id, 'dataset' = dataset, 'uID' = uID, 
                         'seqdepth' = seqdepth, 'minfact' = minfact, 'maxfact' = maxfact)
	
	### Filter the data with respect to total count
	s = apply(Z, 1, sum)
	keep.T = which(s >= filter.threshold.total)
	Z.T = Z[keep.T, ]
	variable.annotations.T = variable.annotations[keep.T, ]
  filtering = paste('total count >=', filter.threshold.total)
	
	### Filter the data with respect to median cpm
	cpm = sweep(Z.T, 2, apply(Z.T, 2, sum), '/') * 1e6
	m = apply(cpm, 1, median)
	keep.C = which(m >= filter.threshold.mediancpm)
	Z.TC = Z.T[keep.C, ]
	variable.annotations.TC = variable.annotations.T[keep.C, ]
  filtering = paste(filtering, "; ", paste('median cpm >=', filter.threshold.mediancpm))
	
  ### Generate sample and variable names
  rownames(Z.TC) <- paste("g", 1:nrow(Z.TC), sep = "")
  colnames(Z.TC) <- paste("sample", 1:ncol(Z.TC), sep = "")
  rownames(sample.annotations) <- colnames(Z.TC)
  rownames(variable.annotations.TC) <- rownames(Z.TC)
  
  data.list.TC = list(count.matrix = Z.TC, variable.annotations = variable.annotations.TC, 
                      sample.annotations = sample.annotations, 
                      filtering = filtering, info.parameters = info.parameters)
  
  ## Save results
  if (!is.null(output.file)) {
    if (strsplit(output.file, "\\.")[[1]][length(strsplit(output.file, "\\.")[[1]])] != "rds") {
      output.file <- sub(strsplit(output.file, "\\.")[[1]][length(strsplit(output.file, "\\.")[[1]])], 
                      "rds", output.file)
    }
    saveRDS(data.list.TC, file = output.file)
  }
  
	return(invisible(data.list.TC))
}

#' Summarize a synthetic data set by some diagnostic plots 
#' 
#' Summarize a synthetic data set (generated by \code{\link{generateSyntheticData}}) by some diagnostic plots.
#' 
#' @param data.set A data set, either an object returned by \code{\link{generateSyntheticData}} or a path to an \code{.rds} object where the data set is stored.
#' @param output.filename The filename of the resulting html report (without the path).
#' @param output.directory The directory where the results will be written. If \code{NULL}, the current working directory is used. 
#' @export
#' @author Charlotte Soneson
#' @examples
#' mydata.obj <- generateSyntheticData(dataset = "mydata", n.vars = 12500, 
#'                                     samples.per.cond = 5, n.diffexp = 1250, 
#'                                     output.file = "mydata.rds")
#' summarizeSyntheticDataSet(data.set = "mydata.rds", 
#'                           output.filename = "mydata_check.rds", 
#'                           output.directory = ".")
summarizeSyntheticDataSet = function(data.set, output.filename, output.directory = ".") {
  if (substr(output.directory, nchar(output.directory),
             nchar(output.directory)) == "/") {
    output.directory <- substr(output.directory, 1,
                               nchar(output.directory) - 1)
  }
  
  ## Generate an .Rmd file
  Rmd.file <- file.path(output.directory, 
                        sub(strsplit(output.filename, "\\.")[[1]][length(strsplit(output.filename,
                                                                                  "\\.")[[1]])], 
                            "Rmd", output.filename))
  codefile = file(Rmd.file, open = 'w')
  writeLines("### Summary of synthetic data set", codefile)
  
  opts_chunk$set(fig.path = file.path(output.directory, "compcodeR_check_figure/"))
  opts_chunk$set(fig.width = 9, fig.height = 7)
  
  if (class(data.set) == "list") {
    data.set <- data.set
  } else if (class(data.set) == "character" & 
               strsplit(data.set, "\\.")[[1]][length(strsplit(data.set, "\\.")[[1]])] == "rds") {
    dataset.filename <- data.set
    data.set <- readRDS(data.set)
    writeLines(paste("Data set from file:", dataset.filename), codefile)
  } else {
    stop("Unknown input type")
  }
  
  ## Print the data parameters
  writeLines(c("```{r settings, echo = FALSE}",
               "print(data.set$info.parameters, sep = '\n')",
               "```"), codefile)
  
  writeLines(c("```{r modifications, echo = FALSE}",
               "  data.set$variable.annotations$differential.expression = as.factor(data.set$variable.annotations$differential.expression)",
               "data.set$variable.annotations$total.nbr.outliers = as.factor(data.set$variable.annotations$n.random.outliers.up.S1 + data.set$variable.annotations$n.random.outliers.up.S2 + data.set$variable.annotations$n.random.outliers.down.S1 + data.set$variable.annotations$n.random.outliers.down.S2 + data.set$variable.annotations$n.single.outliers.up.S1 + data.set$variable.annotations$n.single.outliers.up.S2 + data.set$variable.annotations$n.single.outliers.down.S1 + data.set$variable.annotations$n.single.outliers.down.S2)", 
               "```"), codefile)
  
  ## MA plots, colored by various annotations
  ## Colored by true differential expression status
  writeLines("### MA plot, colored by true differential expression status", codefile)
  writeLines(c("```{r maplot-trueDEstatus, echo = FALSE, dev = 'png', eval = TRUE, include = TRUE, message = FALSE, error = TRUE, warning = TRUE}",
               "ggplot(data.set$variable.annotations, aes(x = A.value, y = M.value, color = differential.expression)) + geom_point() + scale_colour_manual(values = c('black', 'red'))",
               "```"), codefile)

  ## Colored by number of outlier counts
  writeLines("### MA plot, colored by total number of outliers", codefile)
  writeLines(c("```{r maplot-nbroutliers, echo = FALSE, dev = 'png', eval = TRUE, include = TRUE, message = FALSE, error = TRUE, warning = TRUE}",
               "ggplot(data.set$variable.annotations, aes(x = A.value, y = M.value, color = total.nbr.outliers)) + geom_point()",
               "```"), codefile)
  
  ## Plots of estimated log2-fold change (M-value) vs true log2-fold change, colored by true differential expression status
  writeLines("### True log2-fold change vs estimated log2-fold change (M-value)", codefile)
  writeLines(c("```{r logfoldchanges, echo = FALSE, dev = 'png', eval = TRUE, include = TRUE, message = FALSE, error = TRUE, warning = TRUE}",
               "ggplot(data.set$variable.annotations, aes(x = truelog2foldchanges, y = M.value, color = differential.expression)) + geom_point() + scale_colour_manual(values = c('black', 'red'))",
               "```"), codefile)
  
  close(codefile)
  
  knit2html(input = Rmd.file,
            output = sub(".Rmd", ".html", Rmd.file), 
            title = "Synthetic data set summary", 
            envir = new.env())
  
  ## Remove the .Rmd file
  file.remove(Rmd.file)
  
}
