#' The main function to run differential expression analysis
#' 
#' The main function for running differential expression analysis (comparing two conditions), using one of the methods provided in compcodeR or a user-defined method.
#' 
#' @param data.file The path to a \code{.rds} object containing the data on which the differential expression analysis will be performed, for example a data object returned from \code{\link{generateSyntheticData}}.
#' @param result.extent The extension that will be added to the data file name in order to construct the result file name. This can be for example the differential expression method together with a version number. 
#' @param Rmdfunction A function that creates an Rmd file containing the code that should be run to perform the differential expression analysis. 
#' @param output.directory The directory in which the result object will be saved.
#' @param norm.path Logical, whether to include the full (absolute) path to the output object in the saved code. 
#' @param ... Additional arguments that will be passed to the \code{Rmdfunction}, such as parameter choices for the differential expression method.
#' @export
#' @author Charlotte Soneson
#' @examples
#' mydata.obj <- generateSyntheticData(dataset = "mydata", n.vars = 12500, 
#'                                     samples.per.cond = 5, n.diffexp = 1250, 
#'                                     output.file = "mydata.rds")
#' checkDataObject(mydata.obj)
#' listcreateRmd()
#' runDiffExp(data.file = "mydata.rds", result.extent = "voom.limma", 
#'            Rmdfunction = "voom.limma.createRmd", 
#'            output.directory = ".", norm.method = "TMM")
runDiffExp <- function(data.file, result.extent, Rmdfunction, output.directory = ".", norm.path = TRUE, ...) {
  code.file <- "tempcode.Rmd"
  
  if (norm.path) {
    output.directory <- normalizePath(output.directory)
  } else {
    ## Just remove any trailing "/"
    if (substr(output.directory, nchar(output.directory), nchar(output.directory)) == "/") {
      output.directory <- substr(output.directory, 1, nchar(output.directory) - 1)
    }
  }

  ## Extract the file name of the data file (after the last /), and extend it with the 
  ## result.extent (before the .rds) to create the result file name.
  result.file <- file.path(output.directory, 
                           gsub(".rds", paste("_", result.extent, ".rds", sep = ""), 
                                str_split(data.file, "/")[[1]][length(str_split(data.file, "/")[[1]])]))
  
  ## Create the .Rmd file with the differential expression code
  eval(parse(text = Rmdfunction))(data.file, result.file, code.file, ...)
  input.Rmd <- code.file
  
  ## Run the differential expression analysis
  knit(input = input.Rmd, output = str_replace(code.file, ".Rmd", ".md"))
  
  ## Add the code to the result object
  temp.file <- readRDS(result.file)
  temp.file$code <- readLines(str_replace(code.file, ".Rmd", ".md"))
  saveRDS(temp.file, file = result.file)

  ## Remove the temporary code file
  file.remove(code.file)
  file.remove(str_replace(code.file, ".Rmd", ".md")) 
}
