\name{generateSyntheticData}
\alias{generateSyntheticData}
\title{Generate synthetic data sets}
\usage{
  generateSyntheticData(dataset, n.vars, samples.per.cond,
    n.diffexp, repl.id = 1, seqdepth = 1e+07,
    minfact = 0.7, maxfact = 1.4, fraction.upregulated = 1,
    between.group.diffdisp = FALSE,
    filter.threshold.total = 1,
    filter.threshold.mediancpm = 0,
    fraction.non.overdispersed = 0,
    random.outlier.high.prob = 0,
    random.outlier.low.prob = 0,
    single.outlier.high.prob = 0,
    single.outlier.low.prob = 0, effect.size = 1.5,
    output.file = NULL)
}
\arguments{
  \item{dataset}{A name or identifier for the data
  set/simulation settings.}

  \item{n.vars}{The number of simulated genes. Based on the
  filtering conditions (\code{filter.threshold.total} and
  \code{filter.threshold.mediancpm}), the number of genes
  in the final data set may be lower than this number.}

  \item{samples.per.cond}{The number of samples per
  condition.}

  \item{n.diffexp}{The number of differentially expressed
  genes.}

  \item{repl.id}{A replicate ID for the specific simulation
  instance. Useful for example when generating multiple
  count matrices with the same simulation settings.}

  \item{seqdepth}{The base sequencing depth (total number
  of mapped reads). This number is multiplied by a value
  drawn uniformly between \code{minfact} and \code{maxfact}
  for the individual samples to generate data with
  different actual sequencing depths.}

  \item{minfact,maxfact}{The minimum and maximum for the
  uniform distribution used to generate factors that are
  multiplied with \code{seqdepth} to generate individual
  sequencing depths for the simulated samples.}

  \item{fraction.upregulated}{The fraction of the
  differentially expressed genes that is upregulated in
  condition 2 compared to condition 1.}

  \item{between.group.diffdisp}{Whether or not the
  dispersion should be allowed to be different between the
  conditions.}

  \item{filter.threshold.total}{The filter threshold on the
  total count for a gene across all samples. All genes for
  which the total count across all samples is less than the
  threshold will be filtered out.}

  \item{filter.threshold.mediancpm}{The filter threshold on
  the median count per million (cpm) for a gene across all
  samples. All genes for which the median cpm across all
  samples is less than the threshold will be filtered out.}

  \item{fraction.non.overdispersed}{The fraction of the
  genes that should be simulated according to a Poisson
  distribution, without overdispersion. The
  non-overdispersed genes will be divided proportionally
  between the upregulated, downregulated and
  non-differentially expressed genes.}

  \item{random.outlier.high.prob}{The fraction of 'random'
  outliers with unusually high counts.}

  \item{random.outlier.low.prob}{The fraction of 'random'
  outliers with unusually low counts.}

  \item{single.outlier.high.prob}{The fraction of 'single'
  outliers with unusually high counts.}

  \item{single.outlier.low.prob}{The fraction of 'single'
  outliers with unusually low counts.}

  \item{effect.size}{The strength of the differential
  expression, i.e., the effect size, between the two
  conditions.}

  \item{output.file}{If not \code{NULL}, the path to the
  file where the data should be saved. The extension should
  be \code{.rds}, if not it will be changed.}
}
\value{
  The function returns a data object, in the form of a list
  with the following named elements: \itemize{ \item
  \code{count.matrix}: The simulated count matrix, with
  each row representing a gene and each column representing
  a sample. \item \code{variable.annotations}: a data frame
  (with number of rows equal to the number of variables in
  the data set) with the following named columns: \itemize{
  \item \code{truedispersions.S1}: the true dispersion for
  each gene in condition S1. \item
  \code{truedispersions.S2}: the true dispersion for each
  gene in condition S2. \item \code{truemeans.S1}: the true
  mean value for each gene in condition S1. \item
  \code{truemeans.S2}: the true mean value for each gene in
  condition S2. \item \code{n.random.outliers.up.S1}: the
  number of 'random' outliers with extremely high counts
  for each gene in condition S1. \item
  \code{n.random.outliers.up.S2}: the number of 'random'
  outliers with extremely high counts for each gene in
  condition S2. \item \code{n.random.outliers.down.S1}: the
  number of 'random' outliers with extremely low counts for
  each gene in condition S1. \item
  \code{n.random.outliers.down.S2}: the number of 'random'
  outliers with extremely low counts for each gene in
  condition S2. \item \code{n.single.outliers.up.S1}: the
  number of 'single' outliers with extremely high counts
  for each gene in condition S1. \item
  \code{n.single.outliers.up.S2}: the number of 'single'
  outliers with extremely high counts for each gene in
  condition S2. \item \code{n.single.outliers.down.S1}: the
  number of 'single' outliers with extremely low counts for
  each gene in condition S1. \item
  \code{n.single.outliers.down.S2}: the number of 'single'
  outliers with extremely low counts for each gene in
  condition S2. \item \code{M.value}: the M-value (observed
  log2 fold change between condition S1 and condition S2)
  for each gene. \item \code{A.value}: the A-value
  (observed average expression level across condition S1
  and condition S2) for each gene. \item
  \code{truelog2foldchanges}: the true (simulated) log2
  fold changes between condition S1 and condition S2. \item
  \code{upregulation}: a binary vector indicating which
  genes are simulated to be upregulated in condition S2
  compared to condition S1. \item \code{downregulation}: a
  binary vector indicating which genes are simulated to be
  downregulated in condition S2 compared to condition S1.
  \item \code{differential.expression}: a binary vector
  indicating which genes are simulated to be differentially
  expressed in condition S2 compared to condition S1. }
  \item \code{sample.annotations}: a data frame (with the
  number of rows equal to the number of samples) with the
  following named columns: \itemize{ \item
  \code{condition}: the class of each sample. \item
  \code{depth.factor}: the depth factor for each sample.
  This factor, multiplied by \code{seqdepth}, is used as
  the simulated library size for the sample. } \item
  \code{filtering}: information about the filtering that
  has been applied (total count and median cpm). \item
  \code{info.parameters}: a list summarizing the parameters
  that have been used for the simulation (see the
  description above of the arguments to the function for
  more information): \itemize{ \item \code{dataset} \item
  \code{samples.per.cond} \item \code{n.diffexp} \item
  \code{repl.id} \item \code{seqdepth} \item \code{minfact}
  \item \code{maxfact} \item \code{fraction.upregulated}
  \item \code{between.group.diffdisp} \item
  \code{filter.threshold.total} \item
  \code{filter.threshold.mediancpm} \item
  \code{fraction.non.overdispersed} \item
  \code{random.outlier.high.prob} \item
  \code{random.outlier.low.prob} \item
  \code{single.outlier.high.prob} \item
  \code{single.outlier.low.prob} \item \code{effect.size}
  \item \code{uID}: a unique ID that is given to each
  simulated data set. } } If \code{output.file} is not
  \code{NULL}, the object is saved with the given
  \code{output.file} (which should have an \code{.rds}
  extension).
}
\description{
  Generate synthetic count data sets, following the
  simulation strategy detailed in Soneson and Delorenzi
  (2013).
}
\examples{
mydata.obj <- generateSyntheticData(dataset = "mydata", n.vars = 12500,
                                    samples.per.cond = 5, n.diffexp = 1250,
                                    output.file = "mydata.rds")
}
\author{
  Charlotte Soneson
}
\references{
  Soneson C and Delorenzi M (2013): A comparison of methods
  for differential expression analysis of RNA-seq data. BMC
  Bioinformatics 14:91

  Cheung VG, Nayak RR, Wang IX, Elwyn S, Cousins SM, Morley
  M and Spielman RS (2010): Polymorphic cis- and
  trans-regulation of human gene expression. PLoS Biology
  8(9):e1000480

  Frazee AC, Langmead B and Leek JT (2011): ReCount: a
  multi-experiment resource of analysis-ready RNA-seq gene
  count datasets. BMC Bioinformatics 12:449

  Pickrell JK, Marioni JC, Pai AA, Degner JF, Engelhardt
  BE, Nkadori E, Veyrieras JB, Stephens M, Gilad Y and
  Pritchard JK (2010): Understanding mechanisms underlying
  human gene expression variation with RNA sequencing.
  Nature 464, 768-772

  Robles JA, Qureshi SE, Stephen SJ, Wilson SR, Burden CJ
  and Taylor JM (2012): Efficient experimental design and
  analysis strategies for the detection of differential
  expression using RNA-sequencing. BMC Genomics 13:484
}

